@@ -1,5 +1,5 @@
-#ifndef BUILDMANAGER_H
-#define BUILDMANAGER_H
+#ifndef Header_Build_Manager
+#define Header_Build_Manager
 
 #include "mostQtHeaders.h"
 
@@ -64,7 +64,7 @@ struct CommandInfo {
 	QStringList metaSuggestionList;
 	QStringList simpleDescriptionList;
 
-	QString guessCommandLine() const;
+    QString guessCommandLine(const QString texpath="") const;
 	//sets a command (accepts tr("<unknown>"))
 	void setCommandLine(const QString &newCmd);
 
@@ -135,8 +135,9 @@ public:
 	bool hasCommandLine(const QString &program);
 
 	void registerOptions(ConfigManagerInterface &cmi);
-	void readSettings(QSettings &settings);
+    void readSettings(QSettings &settings);
 	void saveSettings(QSettings &settings);
+    void resetDefaultCommands(const QString texPath);
 
 	void checkLatexConfiguration(bool &noWarnAgain);
 
@@ -215,7 +216,6 @@ private:
 
 	void initDefaultCommandNames();
 	static QString guessTerminalExternal(void);
-	void checkOSXElCapitanDeprecatedPaths(QSettings &settings, const QStringList &commands);
 
     CommandInfo &registerCommand(const QString &id, const QString &basename, const QString &displayName, const QString &args, const QString &oldConfig = "", GuessCommandLineFunc guessFunc = nullptr, bool user = false);
 	CommandInfo &registerCommand(const QString &id, const QString &displayname, const QStringList &alternatives, const QString &oldConfig = "", const bool metaCommand = true, const QStringList simpleDescriptions = QStringList());
@@ -271,7 +271,8 @@ public:
 	const QString &getCommandLine();
 	bool showStdout() const;
 	void setShowStdout(bool show);
-	QString *getStdoutBuffer();
+    QString *getStdoutBuffer();
+    Q_INVOKABLE QString getStdout();
 	void setStdoutBuffer(QString *buffer);
     void setStderrBuffer(QString *buffer);
 	void setStdoutCodec(QTextCodec *codec);
