@@ -1,5 +1,5 @@
-#ifndef CONFIGMANAGER_H
-#define CONFIGMANAGER_H
+#ifndef Header_Config_Manager
+#define Header_Config_Manager
 
 #include "mostQtHeaders.h"
 
@@ -102,7 +102,12 @@ public:
 	bool showCommentedElementsInStructure;
 	bool markStructureElementsBeyondEnd;
 	bool markStructureElementsInAppendix;
+    int globalTOCbackgroundOptions;
 	QString referenceCommandsInContextMenu;
+    bool structureShowSingleDoc;
+    bool structureScrollToCurrentPosition;
+
+    bool macroEditorUsesLineWrap;
 
 	//update
 	bool autoUpdateCheck;
@@ -200,6 +205,7 @@ public:
 	QString spellDictDir;
 	QString spellLanguage;
 	QString spell_dic, thesaurus_database;
+    QStringList previouslyUsedDictionaries;
 
 	//debug
 #ifndef QT_NO_DEBUG
@@ -213,6 +219,7 @@ public:
 
 	// input unicode instead of latex command from symbolgrid (if available)
 	bool insertSymbolsAsUnicode;
+    QByteArray stateSymbolsWidget;
 
     // macro repository
     QString URLmacroRepository;
@@ -234,7 +241,7 @@ public:
 	QAction *newManagedAction(QWidget *menu, const QString &id, const QString &text, const char *slotName, const QList<QKeySequence> &shortCuts = QList<QKeySequence>(), const QString &iconFile = "");
     QAction *newManagedAction(QObject *rootMenu,QWidget *menu, const QString &id, const QString &text, QObject *obj,const char *slotName, const QList<QKeySequence> &shortCuts = QList<QKeySequence>(), const QString &iconFile = "");
 	QAction *newManagedAction(QWidget *menu, const QString &id, QAction *act);
-	QAction *newOrLostOldManagedAction(QWidget *menu, const QString &id, const QString &text, const char *slotName, const QList<QKeySequence> &shortCuts = QList<QKeySequence>(), const QString &iconFile = "");
+    QAction *newOrLostOldManagedAction(QWidget *menu, const QString &id, const QString &text, const char *slotName, const QList<QKeySequence> *shortCuts = nullptr, const QString &iconFile = "");
 	QAction *getManagedAction(const QString &id);
     QList<QAction *> getManagedActions(const QString &id);
 	QList<QAction *> getManagedActions(const QStringList &ids, const QString &commonPrefix = "");
@@ -264,7 +271,8 @@ private:
 	void treeWidgetToManagedMenuTo(QTreeWidgetItem *item);
 
 	QTreeWidgetItem *managedLatexMenuToTreeWidget(QTreeWidgetItem *parent, QMenu *menu);
-	void treeWidgetToManagedLatexMenuTo();
+    void treeWidgetToManagedLatexMenuTo(QTreeWidgetItem *item);
+    void scanTreeWidgetForCustomMenuEntries(QMap<QString, QVariant> &foundMenus, QTreeWidgetItem *item, QString prefix);
 
 public:
 	// custom toolbar
@@ -321,6 +329,7 @@ private:
 
 	QList<QTreeWidgetItem *> changedItemsList, superAdvancedItems;
 	QHash<QString, QTreeWidgetItem *> manipulatedMenuTree;
+    QStringList tobeRemovedList;
 
 	QMap<QString, QVariant> manipulatedMenus;
 
@@ -351,6 +360,7 @@ private slots:
 	void menuTreeItemChanged(QTreeWidgetItem *item, int l);
 	void menuTreeNewItem(bool menu = false);
 	void menuTreeNewMenuItem();
+    void menuTreeRevertItem();
 	void toggleVisibleTreeItems(bool show);
 	void activateInternalViewer(bool activated);
 
