@@ -5,12 +5,14 @@
 #include <stdlib.h>
 
 //backtrace is only available on GNU libc
-#ifndef __GLIBC__
+#if !defined(__GLIBC__)&&!defined(Q_OS_WIN32)
 #define NO_CRASH_HANDLER
 #endif
 
 // disable backtrace on ARM as the code does not compile
-#if (defined(arm) || defined(__arm__))
+// disable backtrace on RISC-V. RISC-V does not support stack unwinding using frame pointer.
+// Recommended approach for RISC-V is dwarf cfi info.
+#if (defined(arm) || defined(__arm__) || defined(__riscv))
 #define NO_CRASH_HANDLER
 #endif
 
@@ -129,12 +131,13 @@ struct SimulatedCPU {
 //===========================CRASH HANDLER HEADER==============================
 
 #ifdef OS_IS_UNIX_LIKE
-#include "signal.h"
-#include "unistd.h"
-#include "sys/wait.h"
-#define SAFE_INT volatile sig_atomic_t
+    #include "signal.h"
+    #include "unistd.h"
+    #include "sys/wait.h"
+
+    using SAFE_INT = volatile sig_atomic_t;
 #else
-#define SAFE_INT int
+    using SAFE_INT = int;
 #endif
 
 SAFE_INT crashHandlerType = 1;
@@ -142,11 +145,16 @@ enum { ERR_NONE = 0, ERR_SIGNAL, ERR_ASSERT, ERR_LOOP, ERR_EXCEPTION};
 SAFE_INT lastErrorType = 0;
 volatile void *sigSegvRecoverReturnAddress = 0; //address where it should jump to, if recovering causes another sigsegv
 
-#define CRASH_HANDLER_RECOVER 1
+/*#define CRASH_HANDLER_RECOVER 1
 #define CRASH_HANDLER_PRINT_BACKTRACE_IN_HANDLER 2
 #define CRASH_HANDLER_LOOP_GUARDIAN_DISABLED 4
-#define CRASH_HANDLER_USE_NATIVE_BACKTRACE 8
+#define CRASH_HANDLER_USE_NATIVE_BACKTRACE 8*/
 
+const SAFE_INT
+    CRASH_HANDLER_RECOVER = 1,
+    CRASH_HANDLER_PRINT_BACKTRACE_IN_HANDLER = 2,
+    CRASH_HANDLER_LOOP_GUARDIAN_DISABLED = 4,
+    CRASH_HANDLER_USE_NATIVE_BACKTRACE = 8;
 
 //===========================STACK TRACE PRINTING=========================
 
@@ -290,8 +298,8 @@ bool initDebugHelp()
 
 	LOAD_FUNCTIONREQRET(SymInitialize, "SymInitialize", false);
 
-	if (!(*SymInitialize)(((QSysInfo::windowsVersion() & QSysInfo::WV_DOS_based) == 0) ? GetCurrentProcess() : (HANDLE)GetCurrentProcessId(), 0, true))
-		return false;
+    if (!(*SymInitialize)(true ? GetCurrentProcess() : (HANDLE)GetCurrentProcessId(), 0, true))
+        return false;
 	return true;
 }
 
@@ -366,7 +374,7 @@ geteip:
 	    : "=r"(context.Ebp), "=r"(context.Esp));
 #endif
 	ZeroMemory( &stackFrame, sizeof( stackFrame ) );
-#ifdef CPU_IS_64
+#if defined(CPU_IS_64) || (defined(x86_64) || defined(__x86_64__))
 	DWORD machineType           = IMAGE_FILE_MACHINE_AMD64;
 	stackFrame.AddrPC.Offset    = context.Rip;
 	stackFrame.AddrPC.Mode      = AddrModeFlat;
@@ -434,8 +442,6 @@ QStringList backtrace_symbols_win(void **, int)
 
 #endif
 
-
-
 QString print_backtrace(const SimulatedCPU &state, const QString &message)
 {
 #ifdef Q_OS_WIN32
@@ -816,7 +822,7 @@ void recoverWithStackGuardianPage()
 #endif
 
 
-const char *exceptionCodeToName(int code)
+const char *exceptionCodeToName(long long code)
 {
 	switch (code) {
 #define X(t) case t: return #t;
