@@ -59,11 +59,11 @@ void Editors::addTabWidget(TxsTabWidget *w)
 		if (w->isEmpty()) w->hide();
 	}
 	connect(w, SIGNAL(currentEditorChanged()), changes, SLOT(currentEditorChange()));
-	connect(w, SIGNAL(editorAboutToChangeByTabClick(LatexEditorView *, LatexEditorView *)), this, SLOT(onEditorChangeByTabClick(LatexEditorView *, LatexEditorView *)));
+    connect(w, SIGNAL(editorAboutToChangeByTabClick(LatexEditorView*,LatexEditorView*)), this, SLOT(onEditorChangeByTabClick(LatexEditorView*,LatexEditorView*)));
 	connect(w, SIGNAL(activationRequested()), SLOT(activateTabWidgetFromSender()));
-	connect(w, SIGNAL(closeEditorRequested(LatexEditorView*)), SLOT(requestCloseEditor(LatexEditorView *)));
+    connect(w, SIGNAL(closeEditorRequested(LatexEditorView*)), SLOT(requestCloseEditor(LatexEditorView*)));
 	connect(w, SIGNAL(tabBarContextMenuRequested(QPoint)), SLOT(tabBarContextMenu(QPoint)));
-	connect(w, SIGNAL(tabMoved(int, int)), SIGNAL(editorsReordered()));
+    connect(w, SIGNAL(tabMoved(int,int)), SIGNAL(editorsReordered()));
 }
 
 void Editors::addEditor(LatexEditorView *edView, bool asCurrent)
@@ -469,7 +469,22 @@ void Editors::moveToTabGroup(LatexEditorView *edView, int groupIndex, int target
 		groupIndex = 0;
 	if (groupIndex > tabGroups.length() -1)
 		groupIndex = tabGroups.length() -1;
-	moveToTabGroup(edView, tabGroups[groupIndex], targetIndex);
+    moveToTabGroup(edView, tabGroups[groupIndex], targetIndex);
+}
+/*!
+ * \brief move all editor to tabgroup 0 if there are no editors
+ * This basically "closes" tabgroup 1
+ */
+void Editors::moveAllToGroupZeroifEmpty()
+{
+    if(tabGroups.length()>1 && tabGroups[0]->isEmpty()) {
+        TxsTabWidget *tabGroup = tabGroups[1];
+        if (!tabGroup) return;
+
+        // NOTE: This code assumes exactly two tabGroups
+        foreach (LatexEditorView *edView, tabGroup->editors())
+            moveToTabGroup(edView, tabGroups[0], -1);
+    }
 }
 
 /*!
