@@ -22,6 +22,7 @@ GrammarCheck::GrammarCheck(QObject *parent) :
 GrammarCheck::~GrammarCheck()
 {
 	delete latexParser;
+    delete backend;
 }
 /*!
  * \brief GrammarCheck::init
@@ -38,7 +39,7 @@ void GrammarCheck::init(const LatexParser &lp, const GrammarCheckerConfig &confi
 
         backend = new GrammarCheckLanguageToolJSON(this);
 
-        connect(backend, SIGNAL(checked(uint, int, QList<GrammarError>)), this, SLOT(backendChecked(uint, int, QList<GrammarError>)));
+        connect(backend, SIGNAL(checked(uint,int,QList<GrammarError>)), this, SLOT(backendChecked(uint,int,QList<GrammarError>)));
         connect(backend, SIGNAL(errorMessage(QString)),this,SIGNAL(errorMessage(QString)));
         connect(backend, SIGNAL(languageToolStatusChanged()),this,SLOT(updateLTStatus()));
     }
@@ -96,13 +97,13 @@ struct TokenizedBlock {
 struct CheckRequest {
 	bool pending;
 	QString language;
-	void *doc;
+    LatexDocument *doc;
 	QList<LineInfo> inlines;
 	int firstLineNr;
 	uint ticket;
 	int handledBlocks;
-    CheckRequest(const QString &language, const void *doc, const QList<LineInfo> inlines, const int firstLineNr, const uint ticket):
-		pending(true), language(language), doc(const_cast<void *>(doc)), inlines(inlines), firstLineNr(firstLineNr), ticket(ticket), handledBlocks(0) {}
+    CheckRequest(const QString &language, LatexDocument *doc, const QList<LineInfo> inlines, const int firstLineNr, const uint ticket):
+        pending(true), language(language), doc(doc), inlines(inlines), firstLineNr(firstLineNr), ticket(ticket), handledBlocks(0) {}
 
 	QList<int> linesToSkip;
 
@@ -110,7 +111,7 @@ struct CheckRequest {
 	QVector<QList<GrammarError> > errors;
 };
 
-void GrammarCheck::check(const QString &language, const void *doc, const QList<LineInfo> &inlines, int firstLineNr)
+void GrammarCheck::check(const QString &language, LatexDocument *doc, const QList<LineInfo> &inlines, int firstLineNr)
 {
 	if (shuttingDown || inlines.isEmpty()) return;
 
@@ -163,11 +164,28 @@ const QString punctuationNotFollowedBySpace = "(\"\u00A0";
  * If i > words.length() break;
  * This does always increase i by one. (Note: the checks below are written based on i++)
  * This is used in loops for selectively joining words with spaces. */
-#define CHECK_FOR_SPACE_AND_CONTINUE_LOOP(i, words) i++; \
-  if (i >= words.length()) break; \
-  if (words[i].length() == 1 && punctuationNotPreceededBySpace.contains(words[i][0])) continue; \
-  if (words[i-1].length() == 1 && punctuationNotFollowedBySpace.contains(words[i-1][0])) continue; \
-  if (words[i-1].length() == 2 && words[i-1][1] == '.' && words[i].length() == 2 && words[i][1] == '.') continue; /* abbeviations like "e.g." */ \
+
+
+#define PRECEED_WITH_SPACES(i,words)                                      \
+                                                                        \
+    (i)++;                                                              \
+                                                                        \
+    if((i) >= words.length())                                           \
+        break;                                                          \
+                                                                        \
+    if(words[i].length() == 1                                           \
+        && punctuationNotPreceededBySpace.contains(words[i][0]))        \
+            continue;                                                   \
+                                                                        \
+    if(words[(i) - 1].length() == 1                                     \
+        && punctuationNotFollowedBySpace.contains(words[(i) - 1][0]))   \
+            continue;                                                   \
+                                                                        \
+    if(words[(i) - 1].length() == 2 && words[(i) - 1][1] == '.'         \
+        && words[i].length() == 2 && words[i][1] == '.')                \
+            continue;
+
+
 
 void GrammarCheck::process(int reqId)
 {
@@ -176,7 +194,8 @@ void GrammarCheck::process(int reqId)
 
 	CheckRequest &cr = requests[reqId];
 
-	LIST_RESERVE(cr.linesToSkip, cr.inlines.size());
+    cr.linesToSkip.reserve(cr.inlines.size());
+
 	if (cr.ticket != ticket) {
 		//processing an old request
 		for (int i = 0; i < cr.inlines.size(); i++) {
@@ -327,7 +346,7 @@ void GrammarCheck::process(int reqId)
             joined.reserve(expectedLength + words.length());
             for (int i = 0;;) {
                 joined += words[i];
-                CHECK_FOR_SPACE_AND_CONTINUE_LOOP(i, words)
+                PRECEED_WITH_SPACES(i, words)
                 joined += " ";
 			}
 			backend->check(crTicket, b, crLanguage, joined);
@@ -447,7 +466,7 @@ void GrammarCheck::backendChecked(uint crticket, int subticket, const QList<Gram
 	while (err < backendErrors.size()) {
 		if (backendErrors[err].offset >= curOffset + words[curWord].length()) {
 			curOffset += words[curWord].length();
-			CHECK_FOR_SPACE_AND_CONTINUE_LOOP(curWord, words)
+            PRECEED_WITH_SPACES(curWord, words)
 			curOffset++; //space
 		} else { //if (backendErrors[err].offset >= curOffset) {
 			int trueIndex = tb.indices[curWord] + qMax(0, backendErrors[err].offset - curOffset);
@@ -463,7 +482,7 @@ void GrammarCheck::backendChecked(uint crticket, int subticket, const QList<Gram
 					}
 					break;
 				}
-				CHECK_FOR_SPACE_AND_CONTINUE_LOOP(w, words)
+                PRECEED_WITH_SPACES(w, words)
 				tempOffset++; //space
 			}
 			if (trueLength == -1)
@@ -566,6 +585,8 @@ void GrammarCheckLanguageToolJSON::init(const GrammarCheckerConfig &config)
     server=url;
 
     ltPath = config.languageToolAutorun ? config.languageToolPath : "";
+    ltPath.replace("[txs-settings-dir]", config.configDir);
+    ltPath.replace("[txs-app-dir]", config.appDir);
     if (!ltPath.endsWith("jar")) {
         QStringList jars;
         jars << "/LanguageTool.jar" << "/languagetool-server.jar" << "/languagetool-standalone.jar";
@@ -626,7 +647,7 @@ QString GrammarCheckLanguageToolJSON::url()
 void GrammarCheckLanguageToolJSON::tryToStart()
 {
     if (triedToStart) {
-        if (QDateTime::currentDateTime().toTime_t() - startTime < 60 * 1000 ) {
+        if (QDateTime::currentDateTime().toSecsSinceEpoch() - startTime < 60 * 1000 ) {
             connectionAvailability = Unknown;
             ThreadBreaker::sleep(1);
         }
@@ -636,16 +657,16 @@ void GrammarCheckLanguageToolJSON::tryToStart()
     startTime = 0;
     if (ltPath == "")
         return;
-    if(!QFileInfo(ltPath).exists()){
+    if(!QFileInfo::exists(ltPath)){
         errorText=QString("LT path \" %1 \" not found !").arg(ltPath);
         emit errorMessage(errorText);
         return;
     }
     javaProcess = new QProcess();
-    connect(javaProcess, SIGNAL(finished(int, QProcess::ExitStatus)), javaProcess, SLOT(deleteLater()));
+    connect(javaProcess, SIGNAL(finished(int,QProcess::ExitStatus)), javaProcess, SLOT(deleteLater()));
     connect(this, SIGNAL(destroyed()), javaProcess, SLOT(deleteLater()));
 
-    javaProcess->start(quoteSpaces(javaPath)+ " -cp " + quoteSpaces(ltPath) + " " + ltArguments);
+    javaProcess->start(javaPath,QStringList()<< "-cp" << ltPath << ltArguments.split(" ")); // check sdm
     javaProcess->waitForStarted(500);
     javaProcess->waitForReadyRead(500);
     errorText=javaProcess->readAllStandardError();
@@ -654,7 +675,7 @@ void GrammarCheckLanguageToolJSON::tryToStart()
     }
 
     connectionAvailability = Unknown;
-    startTime = QDateTime::currentDateTime().toTime_t(); //TODO: fix this in year 2106 when hopefully noone uses qt4.6 anymore
+    startTime = QDateTime::currentDateTime().toSecsSinceEpoch(); //TODO: fix this in year 2106 when hopefully noone uses qt4.6 anymore
 }
 
 /*!
@@ -669,7 +690,7 @@ void GrammarCheckLanguageToolJSON::check(uint ticket, uint subticket, const QStr
 {
     if (!nam) {
         nam = new QNetworkAccessManager();
-        connect(nam, SIGNAL(finished(QNetworkReply *)), SLOT(finished(QNetworkReply *)));
+        connect(nam, SIGNAL(finished(QNetworkReply*)), SLOT(finished(QNetworkReply*)));
     }
 
     REQUIRE(nam);
@@ -692,7 +713,7 @@ void GrammarCheckLanguageToolJSON::check(uint ticket, uint subticket, const QStr
 
     QNetworkRequest req(server);
     req.setHeader(QNetworkRequest::ContentTypeHeader, "text/json");
-    QByteArray post;
+    QString post;
     post.reserve(text.length() + 50);
     post.append("language=" + lang + "&text=");
     post.append(QUrl::toPercentEncoding(text, QByteArray(), QByteArray(" ")));
@@ -705,7 +726,7 @@ void GrammarCheckLanguageToolJSON::check(uint ticket, uint subticket, const QStr
     req.setAttribute(AttributeText, text);
     req.setAttribute(AttributeSubTicket, subticket);
 
-    nam->post(req, post);
+    nam->post(req, post.toUtf8());
 }
 /*!
  * \brief GrammarCheckLanguageToolJSON::shutdown
@@ -832,7 +853,7 @@ void GrammarCheckLanguageToolJSON::finished(QNetworkReply *nreply)
 
         QStringList cors;
         QJsonArray repl=obj["replacements"].toArray();
-        foreach (QJsonValue elem, repl) {
+        for(const QJsonValue &elem: repl) {
             QJsonObject i=elem.toObject();
             cors<<i["value"].toString();
         }
@@ -870,3 +891,5 @@ void GrammarCheckLanguageToolJSON::finished(QNetworkReply *nreply)
             check(cr.ticket, cr.subticket, cr.language, cr.text);
     }
 }
+
+#undef PRECEED_WITH_SPACES
