@@ -9,8 +9,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef LATEXEDITORVIEW_H
-#define LATEXEDITORVIEW_H
+#ifndef Header_Latex_Editor_View
+#define Header_Latex_Editor_View
 
 #include "mostQtHeaders.h"
 #include "qdocument.h"
@@ -20,9 +20,10 @@
 #include "cursorposition.h"
 #include "latexcompleter.h"
 #include "help.h"
-class QDocumentLineHandle;
+#include "latexdocument.h"
+//class QDocumentLineHandle;
 
-class LatexDocument;
+//class LatexDocument;
 class QCodeEdit;
 class QEditor;
 class QLineMarkPanel;
@@ -152,7 +153,7 @@ public:
 
 	QDocumentCursor parenthizedTextSelection(const QDocumentCursor &cursor, bool includeParentheses = true);
 	QDocumentCursor findFormatsBegin(const QDocumentCursor &cursor, QSet<int> allowedFormats, QSet<int> allowedLineEndFormats);
-	void setLatexPackageList(QSet<QString> *lst) { latexPackageList = lst; }
+    void setLatexPackageList(std::set<QString> *lst) { latexPackageList = lst; }
 
 	LatexParser lp;
 
@@ -163,6 +164,9 @@ public:
 	bool getSearchIsWords();
 
 	void updateReplamentList(const LatexParser &cmds, bool forceUpdate = false);
+    QMap<QString,QString> getReplacementList(){
+        return mReplacementList;
+    }
 
     void updatePalette(const QPalette & pal);
 
@@ -195,7 +199,7 @@ private:
 	static QVector<bool> grammarFormatsDisabled;
 	static QList<int> formatsList;
 
-	QSet<QString> *latexPackageList;
+    std::set<QString> *latexPackageList;
 
 	friend class DefaultInputBinding;
 	friend class SyntaxCheckTest;
@@ -273,7 +277,11 @@ public slots:
 	void insertHardLineBreaks(int newLength, bool smartScopeSelection, bool joinLines);
 public:
 	enum LineSorting {SortAscending = 0, SortDescending, SortNone, SortRandomShuffle};
-public slots:
+
+    void checkForLinkOverlay(QDocumentCursor cursor);
+    bool hasLinkOverlay() const { return linkOverlay.isValid(); }
+    const LinkOverlay &getLinkOverlay() const { return linkOverlay; }
+
 	void sortSelectedLines(LineSorting sorting, Qt::CaseSensitivity caseSensitivity, bool completeLines, bool removeDuplicates);
 	void viewActivated();
 	void clearOverlays();
@@ -286,10 +294,6 @@ public slots:
 	static QMultiMap<int, QDocumentCursor* > getSelectedLines(QList<QDocumentCursor>& cursors);
 	void alignMirrors();
 
-	void checkForLinkOverlay(QDocumentCursor cursor);
-	bool hasLinkOverlay() const { return linkOverlay.isValid(); }
-	const LinkOverlay &getLinkOverlay() const { return linkOverlay; }
-
 private:
 	void setLinkOverlay(const LinkOverlay &overlay);
 	void removeLinkOverlay();
@@ -304,7 +308,7 @@ public slots:
 	void removeTemporaryHighlight();
 
 	void displayLineGrammarErrorsInternal(int lineNr, const QList<GrammarError> &errors);
-	void lineGrammarChecked(const void *doc, const void *line, int lineNr, const QList<GrammarError> &errors);
+    void lineGrammarChecked(LatexDocument *doc, QDocumentLineHandle *line, int lineNr, const QList<GrammarError> &errors);
 	void updateGrammarOverlays();
 
 	void bibtexSectionFound(QString content);
@@ -342,7 +346,7 @@ signals:
 	void cursorChangeByMouse();
         void focusReceived();
 
-	void linesChanged(QString language, const void *doc, const QList<LineInfo> &lines, int firstLineNr);
+    void linesChanged(QString language, LatexDocument *doc, const QList<LineInfo> &lines, int firstLineNr);
 	void searchBibtexSection(QString file, QString bibId);
 	void openInternalDocViewer(QString package, QString command = "");
 
@@ -352,7 +356,7 @@ private slots:
 	void lineMarkContextMenuRequested(int lineNumber, QPoint globalPos);
 	void foldContextMenuRequested(int lineNumber, QPoint globalPos);
 };
-Q_DECLARE_METATYPE(LatexEditorView *)
+//Q_DECLARE_METATYPE(LatexEditorView *)
 
 
 class BracketInvertAffector: public PlaceHolder::Affector
