@@ -37,7 +37,7 @@ LatexLogWidget::LatexLogWidget(QWidget *parent) :
 	errorTable->setColumnWidth(2, UtilsUi::getFmWidth(fm, "WarningW"));
 	errorTable->setColumnWidth(3, UtilsUi::getFmWidth(fm, "Line WWWWW"));
 	errorTable->setColumnWidth(4, 20 * UtilsUi::getFmWidth(fm, "w"));
-	connect(errorTable, SIGNAL(clicked(const QModelIndex &)), this, SLOT(clickedOnLogModelIndex(const QModelIndex &)));
+    connect(errorTable, SIGNAL(clicked(const QModelIndex&)), this, SLOT(clickedOnLogModelIndex(const QModelIndex&)));
 
 	errorTable->horizontalHeader()->setStretchLastSection(true);
 	errorTable->setMinimumHeight(5 * rowHeight);
@@ -77,7 +77,11 @@ LatexLogWidget::LatexLogWidget(QWidget *parent) :
 
 	QVBoxLayout *vLayout = new QVBoxLayout(); //contains the widgets for the normal mode (OutputTable + OutputLogTextEdit)
 	vLayout->setSpacing(0);
-	vLayout->setMargin(0);
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
+    vLayout->setMargin(0);
+#else
+    vLayout->setContentsMargins(0,0,0,0);
+#endif
 	vLayout->addWidget(infoLabel);
 	vLayout->addWidget(splitter);
 	setLayout(vLayout);
@@ -302,6 +306,10 @@ void LatexLogWidget::filterChanged(bool )
 	if (filterBadBoxAction && filterBadBoxAction->isChecked())
 		lst << logModel->returnString(LT_BADBOX);
 	QString rg = lst.join("|");
-	proxyModel->setFilterRegExp(rg);
+#if QT_VERSION>=QT_VERSION_CHECK(5,12,0)
+    proxyModel->setFilterRegularExpression(rg);
+#else
+    proxyModel->setFilterRegExp(rg);
+#endif
 	proxyModel->setFilterKeyColumn(1);
 }
