@@ -49,10 +49,16 @@ void LatexStyleParser::run()
 		}
 		if (fn.contains('#')) {
 			QStringList lst = fn.split('#');
-			if (!lst.isEmpty())
+            if (!lst.isEmpty()){
 				topPackage = lst.takeFirst();
-			if (!lst.isEmpty())
+            }
+            if (!lst.isEmpty()){
 				fn = lst.last();
+                if(topPackage.isEmpty()){
+                    topPackage = fn;
+                    topPackage.chop(4);
+                }
+            }
 		} else {
 			topPackage = fn;
 			topPackage.chop(4);
@@ -137,14 +143,15 @@ void LatexStyleParser::run()
 
 
 		// if included styles call for additional generation, do it.
-		QStringList included = results.filter(QRegExp("#include:.+"));
+        QStringList included = results.filter(QRegularExpression("#include:.+"));
 		foreach (QString elem, included) {
 			elem = elem.mid(9);
 			if (!QFileInfo("cwl:" + elem + ".cwl").exists()) {
 				QString hlp = kpsewhich(elem + ".sty");
 				if (!hlp.isEmpty()) {
-					if (!topPackage.isEmpty())
+                    if (!topPackage.isEmpty()){
 						elem = topPackage + "#" + elem + ".sty";
+                    }
 					addFile(elem);
 				}
 			}
@@ -164,7 +171,7 @@ void LatexStyleParser::run()
 					}
 				}
 				if (!topPackage.isEmpty() && topPackage != baseName)
-					baseName = topPackage + "#" + baseName;
+                    baseName = topPackage + "#" + baseName;
 				emit scanCompleted(baseName);
 			}
 		}
@@ -364,7 +371,7 @@ bool LatexStyleParser::parseLineEnv(QStringList &results, const QString &line)
 	if (name.contains("@")) {
 		return true;
 	}
-	QString optionStr = rxEnv.cap(2);
+    //QString optionStr = rxEnv.cap(2);
 	//qDebug()<< name << ":"<< optionStr;
 	QString zw = "\\begin{" + name + "}#S";
 	if (!results.contains(zw))
@@ -378,7 +385,7 @@ bool LatexStyleParser::parseLineEnv(QStringList &results, const QString &line)
 
 bool LatexStyleParser::parseLineInput(QStringList &results, const QString &line, QStringList &parsedPackages, const QString &fileName) const
 {
-	static const QRegExp rxInput("\\\\input\\s*\\{?([\\w._]+)");
+    static const QRegExp rxInput("\\\\input\\s*\\{?([\\w._-]+)");
 
 	if (rxInput.indexIn(line) == -1) {
 		return false;
@@ -525,7 +532,7 @@ bool LatexStyleParser::parseLineXparseCommand(QStringList &results, const QStrin
 	if (parseLineXparseArgs(xpArgs, line, pos + pRx->matchedLength()) == false) {
 		return false;
 	}
-	parseLineXparseOutputCwl(results, name, xpArgs.begin(), xpArgs.end(), 1);
+    parseLineXparseOutputCwl(results, name, xpArgs.constBegin(), xpArgs.constEnd(), 1);
 	return true;
 }
 
@@ -545,7 +552,7 @@ bool LatexStyleParser::parseLineXparseEnv(QStringList &results, const QString &l
 	if (parseLineXparseArgs(xpArgs, line, pos + rxComEnv.matchedLength()) == false) {
 		return false;
 	}
-	parseLineXparseOutputCwl(results, "\\begin{" + name + "}", xpArgs.begin(), xpArgs.end(), 1);
+    parseLineXparseOutputCwl(results, "\\begin{" + name + "}", xpArgs.constBegin(), xpArgs.constEnd(), 1);
 	QString zw = "\\end{" + name + "}#S";
 	if (!results.contains(zw)) {
 		results << zw;
@@ -631,31 +638,31 @@ bool LatexStyleParser::parseLineXparseOneArg(XpArg &xpArg, const QString &argDef
 		xpArg.optional = false;
 		xpArg.delimLeft = '{';
 		xpArg.delimRight = '}';
-		xpArg.fixedChar = 0;
+        xpArg.fixedChar = QChar();
 	} else if ((type == 'o') || (type == 'O')) {
 		xpArg.optional = true;
 		xpArg.delimLeft = '[';
 		xpArg.delimRight = ']';
-		xpArg.fixedChar = 0;
+        xpArg.fixedChar = QChar();
 	} else if (type == 's') {
 		xpArg.optional = true;
-		xpArg.delimLeft = 0;
-		xpArg.delimRight = 0;
+        xpArg.delimLeft = QChar();
+        xpArg.delimRight = QChar();
 		xpArg.fixedChar = '*';
 	} else if ((type == 'r') || (type == 'R')) {
 		xpArg.optional = false;
 		xpArg.delimLeft = match.at(1);
 		xpArg.delimRight = match.at(2);
-		xpArg.fixedChar = 0;
+        xpArg.fixedChar = QChar();
 	} else if ((type == 'd') || (type == 'D')) {
 		xpArg.optional = true;
 		xpArg.delimLeft = match.at(1);
 		xpArg.delimRight = match.at(2);
-		xpArg.fixedChar = 0;
+        xpArg.fixedChar = QChar();
 	} else if (type == 't') {
 		xpArg.optional = true;
-		xpArg.delimLeft = 0;
-		xpArg.delimRight = 0;
+        xpArg.delimLeft = QChar();
+        xpArg.delimRight = QChar();
 		xpArg.fixedChar = match.at(1);
 	} else {
 		// Should never happen
@@ -761,7 +768,7 @@ QStringList LatexStyleParser::readPackageTexDef(QString fn) const
 		}
 	}
 	// replace tex env def by latex commands
-	QStringList zw = args.filter(QRegExp("\\\\end.+"));
+    QStringList zw = args.filter(QRegularExpression("\\\\end.+"));
 	foreach (const QString &elem, zw) {
 		QString begin = elem;
 		begin.remove(1, 3);
@@ -830,6 +837,7 @@ QStringList LatexStyleParser::readPackageTracing(QString fn) const
 			if (elem.startsWith("{changing ")  && !elem.contains("@")) {
 				QString zw = elem.mid(10);
 				zw.chop(11);
+                zw=zw.simplified();
 				if (!args.contains(zw + "#S"))
 					args << zw + "#S";
 			}
@@ -837,7 +845,7 @@ QStringList LatexStyleParser::readPackageTracing(QString fn) const
 	}
 
 	// replace tex env def by latex commands
-	QStringList zw = args.filter(QRegExp("\\\\end.+"));
+    QStringList zw = args.filter(QRegularExpression("\\\\end.+"));
 	foreach (const QString &elem, zw) {
 		QString begin = elem;
 		begin.remove(1, 3);
