@@ -60,7 +60,7 @@
 
 
 // We define a currently unused state for indicating animations
-#define State_Animating 0x00000040
+const unsigned int State_Animating = 0x00000040;
 
 // Because designer needs to disable this for widget previews
 // we have a custom property that is inherited
@@ -297,11 +297,9 @@ QPalette panelPalette(const QPalette &oldPalette)
 	QPalette pal = oldPalette;
 	pal.setBrush(QPalette::All, QPalette::WindowText, color);
 	pal.setBrush(QPalette::All, QPalette::ButtonText, color);
-	pal.setBrush(QPalette::All, QPalette::Foreground, color);
 	color.setAlpha(100);
 	pal.setBrush(QPalette::Disabled, QPalette::WindowText, color);
 	pal.setBrush(QPalette::Disabled, QPalette::ButtonText, color);
-	pal.setBrush(QPalette::Disabled, QPalette::Foreground, color);
 	return pal;
 }
 
@@ -660,7 +658,6 @@ void ManhattanStyle::drawPrimitive(PrimitiveElement element, const QStyleOption
 			imagePainter.translate(sx + bsx, sy + bsy);
 
 			if (!(option->state & State_Enabled)) {
-				QColor foreGround(150, 150, 150, 150);
 				imagePainter.setBrush(option->palette.mid().color());
 				imagePainter.setPen(option->palette.mid().color());
 			} else {
@@ -901,7 +898,6 @@ void ManhattanStyle::drawComplexControl(ComplexControl control, const QStyleOpti
 	switch (control) {
 	case CC_ToolButton:
 		if (const QStyleOptionToolButton *toolbutton = qstyleoption_cast<const QStyleOptionToolButton *>(option)) {
-			QString buttonType = widget->property("type").toString();
 			QRect button, menuarea;
 			button = subControlRect(control, toolbutton, SC_ToolButton, widget);
 			menuarea = subControlRect(control, toolbutton, SC_ToolButtonMenu, widget);
@@ -924,25 +920,9 @@ void ManhattanStyle::drawComplexControl(ComplexControl control, const QStyleOpti
 			QStyleOption tool(0);
 			tool.palette = toolbutton->palette;
 			if (toolbutton->subControls & SC_ToolButton) {
-//                if (buttonType == "dockbutton") {
 				tool.rect = button;
 				tool.state = bflags;
 				drawPrimitive(PE_PanelButtonTool, &tool, painter, widget);
-//                }
-				/*else {  // paint status bar button style
-				                    if (bflags & State_Sunken || bflags & State_On)
-				                        drawCornerImage(d->buttonImage_pressed, painter, option->rect, 2, 2, 2, 2);
-				                    else if (bflags & State_Enabled) {
-				#ifndef Q_OS_MAC
-				                        if (bflags & State_MouseOver) {
-				                            drawCornerImage(d->buttonImage, painter, option->rect, 2, 2, 2, 2);
-				                            QColor shade(255, 255, 255, 50);
-				                            painter->fillRect(button.adjusted(1, 1, -1, -1), shade);
-				                        }
-				#endif
-				                    }
-
-				                }*/
 			}
 
 			if (toolbutton->state & State_HasFocus) {
