@@ -119,6 +119,31 @@ static void fillToc(const QDomNode &parent, QTreeWidget *tree, QTreeWidgetItem *
 			fillToc(node, tree, newitem);
 	}
 }
+#if POPPLER_VERSION_MAJOR>0 || POPPLER_VERSION_MINOR>=74
+static void fillOutline(const QVector<Poppler::OutlineItem>toc, QTreeWidget *tree, QTreeWidgetItem *parentItem)
+{
+    QTreeWidgetItem *newitem = nullptr;
+    foreach(Poppler::OutlineItem e,toc) {
+        if (!parentItem)
+            newitem = new QTreeWidgetItem(tree, newitem);
+        else
+            newitem = new QTreeWidgetItem(parentItem, newitem);
+        newitem->setText(0, e.name());
+
+        bool isOpen = e.isOpen();
+
+        if (isOpen)
+            tree->expandItem(newitem);
+
+        if (e.destination()){
+            newitem->setText(1, e.destination()->toString());
+        }
+
+        if (e.hasChildren())
+            fillOutline(e.children(), tree, newitem);
+    }
+}
+#endif
 /*! \class PDFOutlineDock
  *
  * \brief sidepanel for preview
@@ -158,11 +183,21 @@ void PDFOutlineDock::fillInfo()
 {
 	tree->clear();
 	if (!document || document->popplerDoc().isNull()) return;
+
+
+
+#if POPPLER_VERSION_MAJOR>0 || POPPLER_VERSION_MINOR>=74
+    QVector<Poppler::OutlineItem>toc=document->popplerDoc()->outline();
+    if(!toc.isEmpty()){
+        fillOutline(toc, tree, nullptr);
+        connect(tree, SIGNAL(itemClicked(QTreeWidgetItem*,int)), this, SLOT(followTocSelection()));
+#else
 	const QDomDocument *toc = document->popplerDoc()->toc();
 	if (toc) {
         fillToc(*toc, tree, nullptr);
 		connect(tree, SIGNAL(itemClicked(QTreeWidgetItem *, int)), this, SLOT(followTocSelection()));
 		delete toc;
+#endif
 	} else {
 		QTreeWidgetItem *item = new QTreeWidgetItem();
 		item->setText(0, tr("No TOC"));
@@ -235,7 +270,7 @@ void PDFInfoDock::fillInfo()
 		const int id = keys.indexOf(date);
 		if (id != -1) {
 			list->addItem(date + ":");
-			list->addItem(doc->date(date).toLocalTime().toString(Qt::SystemLocaleDate));
+            list->addItem(doc->date(date).toLocalTime().toString());//Qt::SystemLocaleDate)); TODO
 			++i;
 			keys.removeAt(id);
 		}
@@ -302,7 +337,7 @@ QVariant PDFOverviewModel::data ( const QModelIndex &index, int role) const
 			cache[index.row()] = document->renderManager->renderToImage(index.row(), const_cast<QObject *>(o), "updateImage", -1, -1, -1, -1, -1, -1, false).scaled(128, 128, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 		}
 		return cache[index.row()];
-	case Qt::BackgroundColorRole:
+    case Qt::BackgroundRole:
 		return QColor(Qt::gray);
 	}
 	return QVariant();
@@ -873,7 +908,7 @@ void PDFOverviewDock::changeLanguage()
 void PDFOverviewDock::fillInfo()
 {
 	qobject_cast<PDFOverviewModel *>(list->model())->setDocument(document);
-	connect(list->selectionModel(), SIGNAL(currentChanged(QModelIndex, QModelIndex)), this, SLOT(followTocSelection()));
+    connect(list->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)), this, SLOT(followTocSelection()));
 }
 
 void PDFOverviewDock::documentClosed()
