@@ -13,8 +13,8 @@
 **
 ****************************************************************************/
 
-#ifndef _QEDITOR_H_
-#define _QEDITOR_H_
+#ifndef Header_QEditor
+#define Header_QEditor
 
 #include "mostQtHeaders.h"
 
@@ -261,11 +261,11 @@ class QCE_EXPORT QEditor : public QAbstractScrollArea
 		
 		QAction* action(const QString& s);
 		
-		virtual QRect cursorRect() const;
-		virtual QRect selectionRect() const;
-		virtual QRect lineRect(int line) const;
-		virtual QRect cursorRect(const QDocumentCursor& c) const;
-		virtual QRect cursorMircoFocusRect() const;
+        virtual QRectF cursorRect() const;
+        virtual QRectF selectionRect() const;
+        virtual QRectF lineRect(int line) const;
+        virtual QRectF cursorRect(const QDocumentCursor& c) const;
+        virtual QRectF cursorMircoFocusRect() const;
 
 		
 		virtual int getFirstVisibleLine();
@@ -301,7 +301,7 @@ class QCE_EXPORT QEditor : public QAbstractScrollArea
 		void setSilentReloadOnExternalChanges(bool flag) {mSilentReloadOnExternalChanges=flag;}
 		void setUseQSaveFile(bool flag) {m_useQSaveFile=flag;}
 
-		inline int horizontalOffset() const
+        inline qreal horizontalOffset() const
         {
 #if defined Q_OS_MAC
             return horizontalScrollBar()->value();
@@ -309,12 +309,12 @@ class QCE_EXPORT QEditor : public QAbstractScrollArea
             return horizontalScrollBar()->isVisible() ? horizontalScrollBar()->value() : 0;
 #endif
         }
-		inline int verticalOffset() const
+        inline qreal verticalOffset() const
         {
 #if defined Q_OS_MAC
             return verticalScrollBar()->value() * m_doc->getLineSpacing();  // does this work always ?
 #else
-            return verticalScrollBar()->isVisible() ? verticalScrollBar()->value() * m_doc->getLineSpacing() : 0;
+            return verticalScrollBar()->isVisible() ? 1. * verticalScrollBar()->value() * m_doc->getLineSpacing() : 0;
 #endif
         }
 		
@@ -433,7 +433,7 @@ class QCE_EXPORT QEditor : public QAbstractScrollArea
 		void setSoftLimitedLineWrapping(bool on);
 		void setWrapAfterNumChars(int numChars);
 protected:
-		void setWrapLineWidth(int l);
+        void setWrapLineWidth(qreal l);
 		bool writeToFile(const QString &filename, const QByteArray &data);
 public:		
 		virtual void save();
@@ -476,8 +476,8 @@ public slots:
 		void resetZoom();
 		void zoom(int n);
 		
-		void setPanelMargins(int l, int t, int r, int b);
-		void getPanelMargins(int *l, int *t, int *r, int *b) const;
+        void setPanelMargins(qreal l, qreal t, qreal r, qreal b);
+        void getPanelMargins(qreal *l, qreal *t, qreal *r, qreal *b) const;
 		
 		void setTitle(const QString& title);
 		
@@ -612,7 +612,7 @@ public slots:
 
 		void repaintCursor();
 		void ensureVisible(int line);
-		void ensureVisible(const QRect &rect);
+        void ensureVisible(const QRectF &rect);
 		
 	protected:
 		void preInsertUnindent(QDocumentCursor& c, const QString& text, int additionalUnindent);
@@ -623,15 +623,15 @@ public slots:
 
 	public:
 		QDocumentLine lineAtPosition(const QPoint& p) const;
-		QDocumentCursor cursorForPosition(const QPoint& p) const;
+        QDocumentCursor cursorForPosition(const QPoint& p, bool disallowPositionBeyondLine = false) const;
 		
 		void setClipboardSelection();
 		void setCursorPosition(const QPoint& p, bool moveView = true);
 		
 		void setCursorPosition(int line, int index, bool moveView = true);
 		void getCursorPosition(int &line, int &index);
-		bool getPositionBelowCursor(QPoint& offset, int width, int height,bool &above);
-		bool getPositionBelowCursor(QPoint& offset, int width=0, int height=0);
+		bool getPositionBelowCursor(QPointF &offset, int width, int height, bool &above);
+		bool getPositionBelowCursor(QPointF &offset, int width=0, int height=0);
 
 		Q_INVOKABLE void clearCursorMirrors();
 		Q_INVOKABLE void addCursorMirror(const QDocumentCursor& c);
@@ -696,14 +696,14 @@ public slots:
 		
 		bool atPlaceholder();
         bool isMirrored();
-		int m_curPlaceHolder, m_lastPlaceHolder, m_cphOffset;
+        int m_curPlaceHolder, m_cphOffset;
 		bool m_placeHolderSynchronizing; 
 		
 		QList<PlaceHolder> m_placeHolders;
 		
 		int m_state;
 		bool m_selection;
-		QRect m_crect, m_margins;
+        QRectF m_crect, m_margins;
 		QPoint m_clickPoint, m_dragPoint;
 		QBasicTimer m_blink, m_click, m_drag, m_autoScroll;
 
@@ -735,7 +735,7 @@ public slots:
 
 		int m_cursorSurroundingLines;
 		
-		int m_LineWidth;
+        int m_LineWidth;
 		int m_wrapAfterNumChars;
 
 		QPropertyAnimation *m_scrollAnimation;
