@@ -4,7 +4,10 @@
 #include <QBuffer>
 #include "latexparser/latexparser.h"
 
+using std::map;
+using std::pair;
 
+using CharMap = map<pair<char,char>,int>;
 
 /*
 QList<QPair<QString,QString> > latexToPlainWordReplaceList =
@@ -32,6 +35,79 @@ QList<QPair<QString,QString> > latexToPlainWordReplaceList =
 //	<< QPair<QString, QString> ("\"\"","") redunant
  << QPair<QString, QString> ("\\",""); // eliminating backslash which might remain from accents like \"a ...
 */
+
+const CharMap characters {
+
+    //  Umlaut
+
+    { { '"' , 'a' } , 0xE4 },
+    { { '"' , 'e' } , 0xEB },
+    { { '"' , 'i' } , 0xEF },
+    { { '"' , 'o' } , 0xF6 },
+    { { '"' , 'u' } , 0xFC },
+    { { '"' , 'A' } , 0xC4 },
+    { { '"' , 'E' } , 0xCB },
+    { { '"' , 'I' } , 0xCF },
+    { { '"' , 'O' } , 0xD6 },
+    { { '"' , 'U' } , 0xDC },
+    { { '"' , 's' } , 0xDF },
+
+    //  Grave
+
+    { { '`' , 'a' } , 0xE0 },
+    { { '`' , 'e' } , 0xE8 },
+    { { '`' , 'i' } , 0xEC },
+    { { '`' , 'o' } , 0xF2 },
+    { { '`' , 'u' } , 0xF9 },
+    { { '`' , 'A' } , 0xC0 },
+    { { '`' , 'E' } , 0xC8 },
+    { { '`' , 'I' } , 0xCC },
+    { { '`' , 'O' } , 0xD2 },
+    { { '`' , 'U' } , 0xD9 },
+
+    //  Acute
+
+    { { '\'' , 'a' } , 0xE1 },
+    { { '\'' , 'e' } , 0xE9 },
+    { { '\'' , 'i' } , 0xED },
+    { { '\'' , 'o' } , 0xF3 },
+    { { '\'' , 'u' } , 0xFA },
+    { { '\'' , 'y' } , 0xFD },
+    { { '\'' , 'A' } , 0xC1 },
+    { { '\'' , 'E' } , 0xC9 },
+    { { '\'' , 'I' } , 0xCD },
+    { { '\'' , 'O' } , 0xD3 },
+    { { '\'' , 'U' } , 0xDA },
+    { { '\'' , 'Y' } , 0xDD },
+
+    //  Circumflex
+
+    { { '^' , 'a' } , 0xE2 },
+    { { '^' , 'e' } , 0xEA },
+    { { '^' , 'i' } , 0xEE },
+    { { '^' , 'o' } , 0xF4 },
+    { { '^' , 'u' } , 0xFB },
+    { { '^' , 'A' } , 0xC2 },
+    { { '^' , 'E' } , 0xCA },
+    { { '^' , 'I' } , 0xCE },
+    { { '^' , 'O' } , 0xD4 },
+    { { '^' , 'U' } , 0xDB },
+
+    //  Tilde
+
+    { { '~' , 'a' } , 0xE3 },
+    { { '~' , 'n' } , 0xF1 },
+    { { '~' , 'o' } , 0xF5 },
+    { { '~' , 'A' } , 0xC3 },
+    { { '~' , 'N' } , 0xD1 },
+    { { '~' , 'O' } , 0xD5 },
+
+    //  Cedille
+
+    { { 'c' , 'c' } , 0xE7 },
+    { { 'c' , 'C' } , 0xC7 }
+};
+
 /*!
  * \brief transformCharacter
  * Transform a character from a tex encoded to utf
@@ -40,88 +116,14 @@ QList<QPair<QString,QString> > latexToPlainWordReplaceList =
  * \param context
  * \return tranformed character
  */
-QChar transformCharacter(const QChar &c, const QChar &context)
-{
-	// *INDENT-OFF*  (astyle-config)
-	switch (context.toLatin1()) {
-	case '"':  // umlaut
-		switch (c.toLatin1()){
-		case 'a': return QChar(0xE4);
-		case 'e': return QChar(0xEB);
-		case 'i': return QChar(0xEF);
-		case 'o': return QChar(0xF6);
-		case 'u': return QChar(0xFC);
-		case 'A': return QChar(0xC4);
-		case 'E': return QChar(0xCB);
-		case 'I': return QChar(0xCF);
-		case 'O': return QChar(0xD6);
-		case 'U': return QChar(0xDC);
-		case 's': return QChar(0xDF);
-		default: return c;
-		}
-	case '`':  // grave
-		switch (c.toLatin1()){
-		case 'a': return QChar(0xE0);
-		case 'e': return QChar(0xE8);
-		case 'i': return QChar(0xEC);
-		case 'o': return QChar(0xF2);
-		case 'u': return QChar(0xF9);
-		case 'A': return QChar(0xC0);
-		case 'E': return QChar(0xC8);
-		case 'I': return QChar(0xCC);
-		case 'O': return QChar(0xD2);
-		case 'U': return QChar(0xD9);
-		default: return c;
-		}
-	case '\'':  // acute
-		switch (c.toLatin1()){
-		case 'a': return QChar(0xE1);
-		case 'e': return QChar(0xE9);
-		case 'i': return QChar(0xED);
-		case 'o': return QChar(0xF3);
-		case 'u': return QChar(0xFA);
-		case 'y': return QChar(0xFD);
-		case 'A': return QChar(0xC1);
-		case 'E': return QChar(0xC9);
-		case 'I': return QChar(0xCD);
-		case 'O': return QChar(0xD3);
-		case 'U': return QChar(0xDA);
-		case 'Y': return QChar(0xDD);
-		default: return c;
-		}
-	case '^':  // circumflex
-		switch (c.toLatin1()){
-		case 'a': return QChar(0xE2);
-		case 'e': return QChar(0xEA);
-		case 'i': return QChar(0xEE);
-		case 'o': return QChar(0xF4);
-		case 'u': return QChar(0xFB);
-		case 'A': return QChar(0xC2);
-		case 'E': return QChar(0xCA);
-		case 'I': return QChar(0xCE);
-		case 'O': return QChar(0xD4);
-		case 'U': return QChar(0xDB);
-		default: return c;
-		}
-	case '~':  // tilde
-		switch (c.toLatin1()){
-		case 'a': return QChar(0xE3);
-		case 'n': return QChar(0xF1);
-		case 'o': return QChar(0xF5);
-		case 'A': return QChar(0xC3);
-		case 'N': return QChar(0xD1);
-		case 'O': return QChar(0xD5);
-		default: return c;
-		}
-	case 'c':  // cedille
-		switch (c.toLatin1()){
-		case 'c': return QChar(0xE7);
-		case 'C': return QChar(0xC7);
-		default: return c;
-		}
-	}
-	return c;
-	// *INDENT-ON*  (astyle-config)
+QChar transformCharacter(const QChar & character,const QChar & context){
+
+    auto transformation = characters.find({ context.toLatin1() , character.toLatin1() });
+
+    if(transformation == characters.end())
+        return character;
+
+    return QChar(transformation -> second);
 }
 
 QString latexToPlainWord(const QString &word)
@@ -226,9 +228,10 @@ QString textToLatex(const QString &text)
 	QList<QPair<QString, QString> > replaceList;
 	// replacements for resevered characters according to
 	// http://en.wikibooks.org/wiki/LaTeX/Basics#Reserved_Characters
-	replaceList.append(QPair<QString, QString> ("\\", "\\textbackslash{}"));
-	replaceList.append(QPair<QString, QString> ("{", "\\{"));
-	replaceList.append(QPair<QString, QString> ("}", "\\}"));
+    QString result = text;
+    result.replace("{", "\\{");
+    result.replace("}", "\\}");
+    result.replace(QRegularExpression("\\\\(?![{}])"),"\\textbackslash{}");
 	replaceList.append(QPair<QString, QString> ("#", "\\#"));
 	replaceList.append(QPair<QString, QString> ("$", "\\$"));
 	replaceList.append(QPair<QString, QString> ("%", "\\%"));
@@ -237,10 +240,12 @@ QString textToLatex(const QString &text)
 	replaceList.append(QPair<QString, QString> ("_", "\\_"));
 	replaceList.append(QPair<QString, QString> ("^", "\\^{}"));
 
-	QString result = text;
+
 	for (QList<QPair<QString, QString> >::const_iterator it = replaceList.begin(); it != replaceList.end(); ++it)
 		result.replace(it->first, it->second);
 
+	result.replace(QRegularExpression("\"(.*?)\""), "``\\1''");
+
 	return result;
 }
 
@@ -305,17 +310,22 @@ QString latexToText(QString s)
 }
 
 // joins all the input lines trimming whitespace. A new line is started on comments and empty lines
-QStringList joinLinesExceptCommentsAndEmptyLines(const QStringList &lines)
-{
-#define flush_tmpLine() if (!tmpLine.isEmpty()) { joinedLines.append(tmpLine); tmpLine.clear(); }
+QStringList joinLinesExceptCommentsAndEmptyLines(const QStringList &lines){
 
 	QStringList joinedLines;
 	QString tmpLine;
+
+    #define FLUSH_TMPLINE()                      \
+        if(!tmpLine.isEmpty()){             \
+            joinedLines.append(tmpLine);    \
+            tmpLine.clear();                \
+        }
+
 	foreach (const QString &l, lines) {
 		QString rtrimmedLine = trimRight(l);
 
 		if (rtrimmedLine.isEmpty()) { // empty line as separator
-			flush_tmpLine();
+            FLUSH_TMPLINE();
 			joinedLines.append(rtrimmedLine);
 			continue;
 		}
@@ -327,15 +337,19 @@ QStringList joinLinesExceptCommentsAndEmptyLines(const QStringList &lines)
 		}
 		int commentStart = LatexParser::commentStart(rtrimmedLine);
 		if (commentStart >= 0) {
-			flush_tmpLine();
+            FLUSH_TMPLINE();
 		}
 	}
-	flush_tmpLine();
+
+    FLUSH_TMPLINE();
+
+    #undef FLUSH_TMPLINE
+
 	return joinedLines;
 }
 
 // splits lines after maximal number of chars while keeping track of indentation and comments
-QStringList splitLines(const QStringList &lines, int maxCharPerLine, const QRegExp &breakChars)
+QStringList splitLines(const QStringList &lines, int maxCharPerLine, const QRegularExpression &breakChars)
 {
 	QStringList splittedLines;
 	int maxIndent = maxCharPerLine / 2 * 3;
@@ -408,7 +422,7 @@ QString trimRight(const QString &s)
 QString findToken(const QString &line, const QString &token)
 {
 	int tagStart = line.indexOf(token);
-	int commentStart = line.indexOf(QRegExp("(^|[^\\\\])%")); // find start of comment (if any)
+    int commentStart = line.indexOf(QRegularExpression("(^|[^\\\\])%")); // find start of comment (if any)
 	if (tagStart != -1 && (commentStart > tagStart || commentStart == -1)) {
 		tagStart += token.length();
 		int tagEnd = line.indexOf("}", tagStart);
@@ -430,7 +444,7 @@ QString findToken(const QString &line, const QString &token)
 QString findToken(const QString &line, const QString &token, int &start)
 {
 	int tagStart = line.indexOf(token, start);
-	int commentStart = line.indexOf(QRegExp("(^|[^\\\\])%")); // find start of comment (if any)
+    int commentStart = line.indexOf(QRegularExpression("(^|[^\\\\])%")); // find start of comment (if any)
 	if (tagStart != -1 && (commentStart > tagStart || commentStart == -1)) {
 		tagStart += token.length();
 		int tagEnd = line.indexOf("}", tagStart);
@@ -456,7 +470,7 @@ QString findToken(const QString &line, QRegExp &token)
 	int tagStart = 0;
 	QString s = line;
 	tagStart = token.indexIn(line);
-	int commentStart = line.indexOf(QRegExp("(^|[^\\\\])%")); // find start of comment (if any)
+    int commentStart = line.indexOf(QRegularExpression("(^|[^\\\\])%")); // find start of comment (if any)
 	if (tagStart != -1 && (commentStart > tagStart || commentStart == -1)) {
 		s = s.mid(tagStart + token.cap(0).length(), s.length());
 		return s;
@@ -469,7 +483,7 @@ bool findTokenWithArg(const QString &line, const QString &token, QString &outNam
 	outName = "";
 	outArg = "";
 	int tagStart = line.indexOf(token);
-	int commentStart = line.indexOf(QRegExp("(^|[^\\\\])%")); // find start of comment (if any)
+    int commentStart = line.indexOf(QRegularExpression("(^|[^\\\\])%")); // find start of comment (if any)
 	if (tagStart != -1 && (commentStart > tagStart || commentStart == -1)) {
 		tagStart += token.length();
 		int tagEnd = line.indexOf("}", tagStart);
@@ -613,6 +627,25 @@ QRegExp generateRegExp(const QString &text, const bool isCase, const bool isWord
 	return m_regexp;
 }
 
+QRegularExpression generateRegularExpression(const QString &text, const bool isCase, const bool isWord, const bool isRegExp)
+{
+    QRegularExpression::PatternOption po = isCase ? QRegularExpression::NoPatternOption : QRegularExpression::CaseInsensitiveOption;
+    QRegularExpression m_regexp;
+    if ( isRegExp ) {
+        m_regexp = QRegularExpression(text,  po);
+    } else if ( isWord ) {
+        //todo: screw this? it prevents searching of "world!" and similar things
+        //(qtextdocument just checks the surrounding character when searching for whole words, this would also allow wholewords|regexp search)
+        m_regexp = QRegularExpression(
+                       QString("\\b%1\\b").arg(QRegularExpression::escape(text)),
+                       po
+                   );
+    } else {
+        m_regexp = QRegularExpression(QRegularExpression::escape(text), po);
+    }
+    return m_regexp;
+}
+
 QStringList regExpFindAllMatches(const QString &searchIn, const QRegExp &regexp, int cap)
 {
 	int offset = regexp.indexIn(searchIn);
@@ -624,6 +657,19 @@ QStringList regExpFindAllMatches(const QString &searchIn, const QRegExp &regexp,
 	return res;
 }
 
+
+QStringList regularExpressionFindAllMatches(const QString &searchIn, const QRegularExpression &regexp, int cap)
+{
+    QRegularExpressionMatch match = regexp.match(searchIn);
+    int offset=match.capturedStart();
+    QStringList res;
+    while (offset > -1) {
+        res << match.captured(cap);
+        match = regexp.match(searchIn,offset+match.capturedLength());
+        offset = match.capturedStart();
+    }
+    return res;
+}
 /*!
  * a multi-match equivalent of QString::indexOf(QString)
  */
@@ -643,7 +689,7 @@ QList<int> indicesOf(const QString &line, const QString &word, Qt::CaseSensitivi
 /*!
  * a multi-match equivalent of QString::indexOf(QRegExp)
  */
-QList<int> indicesOf(const QString &line, const QRegExp &rx)
+QList<int> indicesOf(const QString &line, const QRegularExpression &rx)
 {
 	QList<int> columns;
 	int col = 0;
@@ -839,7 +885,7 @@ QString removeAccents(const QString &s) {
 QString makeLatexLabel(const QString &s) {
 	QString sNorm = removeAccents(s).normalized(QString::NormalizationForm_KD).toLower();
 	sNorm.replace(' ', '-');
-	sNorm.remove(QRegExp("[^a-z0-9\\-]"));
+    sNorm.remove(QRegularExpression("[^a-z0-9\\-]"));
 	return sNorm;
 }
 
@@ -847,19 +893,25 @@ QString makeLatexLabel(const QString &s) {
  *  This respects quoted arguments. Output redirection operators are separate tokens
  */
 QStringList tokenizeCommandLine(const QString &commandLine) {
-#define FLUSH(x) { if (!x.isEmpty()) { result << x; } x = ""; }
-	QStringList result;
+
+    QStringList result;
 	QString currentToken = "";
 	currentToken.reserve(30);
 	bool inQuote = false;
 	bool escape= false;
 
+    #define FLUSH(value)        \
+        if(!(value).isEmpty())  \
+            result << (value);  \
+                                \
+        (value) = "";
+
 	foreach (const QChar &c, commandLine) {
 		if (c.isSpace()) {
 			if (inQuote) {
 				currentToken.append(c);
 			} else {
-				FLUSH(currentToken)
+                FLUSH(currentToken)
 			}
 		} else if (c == '\\') {
 			escape = !escape;
@@ -873,21 +925,23 @@ QStringList tokenizeCommandLine(const QString &commandLine) {
 				currentToken.append(c);
 			} else if (currentToken == "2"){
 				currentToken.append(c);
-				FLUSH(currentToken);
+                FLUSH(currentToken)
 			} else {
-				FLUSH(currentToken)
+                FLUSH(currentToken)
 				currentToken = c;
-				FLUSH(currentToken)
+                FLUSH(currentToken)
 			}
 		} else {
 			currentToken.append(c);
 		}
 		escape = false;
 	}
-	FLUSH(currentToken)
+
+    FLUSH(currentToken)
+
+    #undef FLUSH
 
 	return result;
-#undef FLUSH
 }
 
 QStringList extractOutputRedirection(const QStringList &commandArgs, QString &stdOut, QString &stdErr) {
@@ -1045,8 +1099,3 @@ bool addMostRecent(const QString &item, QStringList &mostRecentList, int maxLeng
 	return changed;
 }
 
-
-#define GCC_VERSION (__GNUC__ * 10000 \
-                               + __GNUC_MINOR__ * 100 \
-                               + __GNUC_PATCHLEVEL__)
-
