@@ -129,6 +129,7 @@ void SyntaxCheck::run()
 		//if(newRanges.isEmpty()) continue;
 		newLine.dlh->lockForWrite();
 		if (newLine.ticket == newLine.dlh->getCurrentTicket()) { // discard results if text has been changed meanwhile
+            newLine.dlh->setCookie(QDocumentLine::LEXER_COOKIE,QVariant::fromValue<TokenList>(tl));
             foreach (const Error &elem, newRanges){
                 if(!mSyntaxChecking && (elem.type!=ERR_spelling) && (elem.type!=ERR_highlight) ){
                     // skip all syntax errors
@@ -137,6 +138,10 @@ void SyntaxCheck::run()
                 int fmt= elem.type == ERR_spelling ? SpellerUtility::spellcheckErrorFormat : syntaxErrorFormat;
                 fmt= elem.type == ERR_highlight ? elem.format : fmt;
                 newLine.dlh->addOverlayNoLock(QFormatRange(elem.range.first, elem.range.second, fmt));
+            }
+            // add comment hightlight if present
+            if(commentStart.first>=0){
+                newLine.dlh->addOverlayNoLock(QFormatRange(commentStart.first, newLine.dlh->length()-commentStart.first, mFormatList["comment"]));
             }
 			// active envs
 			QVariant oldEnvVar = newLine.dlh->getCookie(QDocumentLine::STACK_ENVIRONMENT_COOKIE);
@@ -203,6 +208,9 @@ QString SyntaxCheck::getErrorAt(QDocumentLineHandle *dlh, int pos, StackEnvironm
 		if (elem.range.first > pos) break;
 		result = elem.type;
 	}
+    if(result==ERR_highlight){
+        result=ERR_none; // filter out accidental highlight detection (test only)
+    }
 	// now generate Error message
 
 	QStringList messages;  // indices have to match ErrorType
@@ -475,10 +483,10 @@ bool SyntaxCheck::stackContainsDefinition(const TokenStack &stack) const
 * \param stack token stack at start of line
 * \param ticket ticket number for current processed line
 */
-void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnvironment &activeEnv, QDocumentLineHandle *dlh, TokenList tl, TokenStack stack, int ticket,int commentStart)
+void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnvironment &activeEnv, QDocumentLineHandle *dlh, TokenList &tl, TokenStack stack, int ticket,int commentStart)
 {
 	// do syntax check on that line
-	int cols = containsEnv(*ltxCommands, "tabular", activeEnv);
+    //int cols = containsEnv(*ltxCommands, "tabular", activeEnv);
 
     // special treatment for empty lines with $/$$ math environmens
     // latex treats them as error, so do we
@@ -497,7 +505,12 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 
     // check command-words
 	for (int i = 0; i < tl.length(); i++) {
-		Token tk = tl.at(i);
+        Token &tk = tl[i];
+        // remove top env if column exceeds columnlimit
+        // used for formula -> brace -> {....}
+        if(!activeEnv.isEmpty() && activeEnv.top().endingColumn>=0 && tk.start>activeEnv.top().endingColumn){
+            Environment env=activeEnv.pop();
+        }
 		// ignore commands in definition arguments e.g. \newcommand{cmd}{definition}
 		if (stackContainsDefinition(stack)) {
 			Token top = stack.top();
@@ -550,10 +563,22 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
             }else{
                 elem.format=mFormatList["math"];
             }
+            if(tk.type==Token::braces){
+                // add to active env
+                Environment env;
+                env.name = "math";
+                env.id = 1; // to be changed
+                env.dlh = dlh;
+                env.ticket = ticket;
+                env.level = tk.level;
+                env.startingColumn=tk.start+1;
+                env.endingColumn=tk.start+tk.length-1;
+                activeEnv.push(env);
+            }
             newRanges.append(elem);
         }
         // spell checking
-        if (speller->inlineSpellChecking && tk.type == Token::word && (tk.subtype == Token::text || tk.subtype == Token::title || tk.subtype == Token::shorttitle || tk.subtype == Token::todo || tk.subtype == Token::none)  && tk.length >= 3 && speller) {
+        if (speller->inlineSpellChecking && tk.type == Token::word && (tk.subtype == Token::text || tk.subtype == Token::title || tk.subtype == Token::shorttitle || tk.subtype == Token::todo || tk.subtype == Token::none)  && speller) {
             int tkLength=tk.length;
             QString word = tk.getText();
             if(i+1 < tl.length()){
@@ -580,10 +605,21 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                 }
             }
             word = latexToPlainWordwithReplacementList(word, mReplacementList); //remove special chars
-            if (speller->hideNonTextSpellingErrors && (containsEnv(*ltxCommands, "math", activeEnv)||containsEnv(*ltxCommands, "picture", activeEnv))){
+            if (speller->hideNonTextSpellingErrors && (containsEnv(*ltxCommands, "math", activeEnv)||containsEnv(*ltxCommands, "picture", activeEnv)) && tk.subtype!=Token::text){
                 word.clear();
+                tk.ignoreSpelling=true;
+            }else{
+                tk.ignoreSpelling=false;
+                if(containsEnv(*ltxCommands, "math", activeEnv)){
+                    // in math env, highlight as math-text !
+                    Error elem;
+                    elem.type = ERR_highlight;
+                    elem.format=mFormatList["#mathText"];
+                    elem.range = QPair<int, int>(tk.start, tk.length);
+                    newRanges.append(elem);
+                }
             }
-            if (!word.isEmpty() && !speller->check(word) ) {
+            if (tkLength>=3 && !word.isEmpty() && !speller->check(word) ) {
                 if (word.endsWith('-') && speller->check(word.left(word.length() - 1)))
                     continue; // word ended with '-', without that letter, word is correct (e.g. set-up / german hypehantion)
                 if(word.endsWith('.')){
@@ -660,12 +696,12 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
             // command highlighing
             // this looks slow
             // TODO: optimize !
-            for(const Environment &env:activeEnv){
+            foreach(const Environment &env,activeEnv){
                 if(!env.dlh)
                     continue; //ignore "normal" env
                 if(env.name=="document")
                     continue; //ignore "document" env
-                for(const QString &key: mFormatList.keys()){
+                foreach(const QString &key, mFormatList.keys()){
                     if(key.at(0)=='#'){
                         QStringList altEnvs = ltxCommands->environmentAliases.values(env.name);
                         altEnvs<<env.name;
@@ -705,12 +741,12 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 							}
 						}
 						// get new cols
-						cols = containsEnv(*ltxCommands, "tabular", activeEnv);
+                        //cols = containsEnv(*ltxCommands, "tabular", activeEnv);
 					}
                     // handle higlighting
                     QStringList altEnvs = ltxCommands->environmentAliases.values(env);
                     altEnvs<<env;
-                    for(const QString &key: mFormatList.keys()){
+                    foreach(const QString &key, mFormatList.keys()){
                         if(altEnvs.contains(key)){
                             Error elem;
                             int start= closingEnv.dlh==dlh ? closingEnv.startingColumn : 0;
@@ -802,9 +838,9 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 				QSet<QString> translationMap=ltxCommands->possibleCommands.value("%columntypes");
 				QStringList res = LatexTables::splitColDef(option);
 				QStringList res2;
-				for(auto &elem: res){
+                foreach(const auto &elem, res){
 					bool add=true;
-					for(auto i:translationMap){
+                    foreach(const auto &i, translationMap){
 						if(i.left(1)==elem && add){
 							res2 << LatexTables::splitColDef(i.mid(1));
 							add=false;
@@ -814,7 +850,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 						res2<<elem;
 					}
 				}
-				cols = res2.count();
+                int cols = res2.count();
 				tp.id = cols;
 			}
 			activeEnv.push(tp);
@@ -896,7 +932,13 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 						elem.range = QPair<int, int>(tk.start, tk.length);
 						elem.type = ERR_tooManyCols;
 						newRanges.append(elem);
-					}
+                    }else{
+                        Error elem;
+                        elem.range = QPair<int, int>(tk.start, tk.length);
+                        elem.type = ERR_highlight;
+                        elem.format=mFormatList.value("align-ampersand");
+                        newRanges.append(elem);
+                    }
 					continue;
 				}
 
@@ -942,12 +984,12 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
             // command highlighing
             // this looks slow
             // TODO: optimize !
-            for(const Environment &env:activeEnv){
+            foreach(const Environment &env,activeEnv){
                 if(!env.dlh)
                     continue; //ignore "normal" env
                 if(env.name=="document")
                     continue; //ignore "document" env
-                for(const QString &key: mFormatList.keys()){
+                foreach(const QString &key, mFormatList.keys()){
                     if(key.at(0)=='#'){
                         QStringList altEnvs = ltxCommands->environmentAliases.values(env.name);
                         altEnvs<<env.name;
@@ -1021,7 +1063,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 
 			// search stored keyvals
 			QString elem;
-			foreach (elem, ltxCommands->possibleCommands.keys()) {
+            foreach(elem, ltxCommands->possibleCommands.keys()) {
 				if (elem.startsWith("key%") && elem.mid(4) == command)
 					break;
 				if (elem.startsWith("key%") && elem.mid(4, command.length()) == command && elem.mid(4 + command.length(), 1) == "/" && !elem.endsWith("#c")) {
@@ -1080,23 +1122,17 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 		if (tk.subtype == Token::keyVal_val) {
 			//figure out keyval
 			QString word = line.mid(tk.start, tk.length);
+            if(word=="{"){
+                continue; // assume open brace is always valid
+            }
 			// first get command
-			Token cmd = Parsing::getCommandTokenFromToken(tl, tk);
-			QString command = line.mid(cmd.start, cmd.length);
-			// figure out key
-			QString key;
-			for (int k = i - 1; k >= 0; k--) {
-				Token elem = tl.at(k);
-				if (elem.level == tk.level - 1) {
-					if (elem.type == Token::keyVal_key) {
-						key = line.mid(elem.start, elem.length);
-					}
-					break;
-				}
-			}
+            QString command = tk.optionalCommandName;
+            int index=command.indexOf('/');
+            QString key=command.mid(index+1);
+            command=command.left(index);
 			// find if values are defined
 			QString elem;
-			foreach (elem, ltxCommands->possibleCommands.keys()) {
+            foreach(elem, ltxCommands->possibleCommands.keys()) {
 				if (elem.startsWith("key%") && elem.mid(4) == command)
 					break;
 				if (elem.startsWith("key%") && elem.mid(4, command.length()) == command && elem.mid(4 + command.length(), 1) == "/" && !elem.endsWith("#c")) {
@@ -1169,19 +1205,26 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 	}
     if(!activeEnv.isEmpty()){
         //check active env for env highlighting (math,verbatim)
-        for(const Environment &env: activeEnv){
-            QStringList altEnvs = ltxCommands->environmentAliases.values(env.name);
-            altEnvs<<env.name;
-            for(const QString &key: mFormatList.keys()){
+        QStack<Environment>::Iterator it=activeEnv.begin();
+        while(it!=activeEnv.end()){
+            QStringList altEnvs = ltxCommands->environmentAliases.values(it->name);
+            altEnvs<<it->name;
+            foreach(const QString &key, mFormatList.keys()){
                 if(altEnvs.contains(key)){
                     Error elem;
-                    int start= env.dlh==dlh ? env.startingColumn : 0;
+                    int start= it->dlh==dlh ? it->startingColumn : 0;
                     elem.range = QPair<int, int>(start, commentStart>=0 ? commentStart-start : line.length()-start);
                     elem.type = ERR_highlight;
                     elem.format=mFormatList.value(key);
                     newRanges.prepend(elem);  // draw this first and then other on top (e.g. keyword highlighting) !
                 }
             }
+            if(it->endingColumn>-1){
+                activeEnv.erase(it);
+            }else{
+                ++it;
+            }
         }
+
     }
 }
