@@ -6,10 +6,10 @@
 #include "scriptengine.h"
 #include "configmanager.h"
 
-QStringList LatexTables::tabularNames = QStringList() << "tabular" << "array" << "longtable" << "supertabular" << "tabu" << "longtabu"
+QSet<QString> LatexTables::tabularNames = QSet<QString>() << "tabular" << "array" << "longtable" << "supertabular" << "tabu" << "longtabu"
                                         << "IEEEeqnarray" << "xtabular" << "xtabular*" << "mpxtabular" << "mpxtabular*";
-QStringList LatexTables::tabularNamesWithOneOption = QStringList() << "tabular*" << "tabularx" << "tabulary";
-QStringList LatexTables::mathTables = QStringList() << "align" << "align*" << "array" << "matrix" << "matrix*" << "bmatrix" << "bmatrix*"
+QSet<QString> LatexTables::tabularNamesWithOneOption = QSet<QString>() << "tabular*" << "tabularx" << "tabulary";
+QSet<QString> LatexTables::mathTables = QSet<QString>() << "align" << "align*" << "array" << "matrix" << "matrix*" << "bmatrix" << "bmatrix*"
                                       << "Bmatrix" << "Bmatrix*" << "pmatrix" << "pmatrix*" << "vmatrix" << "vmatrix*"
                                       << "Vmatrix" << "Vmatrix*" << "split" << "multline" << "multline*"
                                       << "gather" << "gather*" << "flalign" << "flalign*" << "alignat" << "alignat*"
@@ -47,7 +47,7 @@ void LatexTables::addRow(QDocumentCursor &c, const int numberOfColumns )
 				cur.insertText("\\\\\n");
 			} else {
 				ch.movePosition(2, QDocumentCursor::NextCharacter, QDocumentCursor::KeepAnchor);
-				if (ch.selectedText().contains(QRegExp("^\\S+$"))) {
+                if (ch.selectedText().contains(QRegularExpression("^\\S+$"))) {
 					cur.movePosition(1, QDocumentCursor::PreviousCharacter);
 					cur.insertText("\\\\\n");
 				}
@@ -155,7 +155,7 @@ void LatexTables::addColumn(QDocument *doc, const int lineNumber, const int afte
 			int res = findNextToken(ch, tokens, true, true);
 			if (res == 0) {
 				ch.movePosition(2, QDocumentCursor::NextCharacter, QDocumentCursor::KeepAnchor);
-				if (ch.selectedText().contains(QRegExp("^\\S+$")))
+                if (ch.selectedText().contains(QRegularExpression("^\\S+$")))
 					break;
 			}
 		}
@@ -416,10 +416,10 @@ int LatexTables::getColumn(QDocumentCursor &cur)
 	int result = findNextToken(c, tokens, true, true);
 	if (result == 0) c.movePosition(2, QDocumentCursor::NextCharacter, QDocumentCursor::KeepAnchor);
     if (result == 1) c.movePosition(15, QDocumentCursor::NextCharacter, QDocumentCursor::KeepAnchor);
-	if (c.lineNumber() == cur.lineNumber() && c.selectedText().contains(QRegExp("^\\s*$"))) {
+    if (c.lineNumber() == cur.lineNumber() && c.selectedText().contains(QRegularExpression("^\\s*$"))) {
 		c.movePosition(1, QDocumentCursor::EndOfLine, QDocumentCursor::KeepAnchor);
 		QString zw = c.selectedText();
-		if (zw.contains(QRegExp("^\\s*$"))) return -1;
+        if (zw.contains(QRegularExpression("^\\s*$"))) return -1;
 	}
 
 	c.clearSelection();
@@ -554,7 +554,7 @@ bool LatexTables::inTableEnv(QDocumentCursor &cur)
 		if (!env.startsWith("{") || !env.endsWith("}")) return -1;
 		env = env.mid(1);
 		env.chop(1);
-		if (tabularNames.contains(env, Qt::CaseSensitive) || tabularNamesWithOneOption.contains(env, Qt::CaseSensitive)) {
+        if (tabularNames.contains(env) || tabularNamesWithOneOption.contains(env)) {
 			int result = findNextToken(c, QStringList());
 			if (result != -2) return false;
 			if (c.lineNumber() > cur.lineNumber()) return true;
@@ -602,7 +602,7 @@ void LatexTables::addHLine(QDocumentCursor &cur, const int numberOfLines, const
 		if (remove) {
 			QDocumentCursor c2(c);
 			result = findNextToken(c, hline, true);
-			if (c.selectedText().contains(QRegExp("^\\s*\\\\hline$"))) {
+            if (c.selectedText().contains(QRegularExpression("^\\s*\\\\hline$"))) {
 				c.removeSelectedText();
 			} else {
 				c = c2;
@@ -612,7 +612,7 @@ void LatexTables::addHLine(QDocumentCursor &cur, const int numberOfLines, const
 			QString text = c.line().text();
 			int col = c.columnNumber();
 			int pos_hline = text.indexOf(" \\hline", col);
-			if (pos_hline < 0 || !text.mid(col, pos_hline - col).contains(QRegExp("^\\s*$"))) {
+            if (pos_hline < 0 || !text.mid(col, pos_hline - col).contains(QRegularExpression("^\\s*$"))) {
 				c.insertText(" \\hline");
 				if (!c.atLineEnd()) c.insertText("\n");
 			}
@@ -1009,7 +1009,7 @@ LatexTableLine *LatexTableModel::parseNextLine(const QString &text, int &startCo
 	// ceck for meta line commands at beginning of line
 	bool recheck = true;
     if(line.startsWith("%") && recheck){
-        int behind=line.indexOf(QRegExp("[\\n\\r]"));
+        int behind=line.indexOf(QRegularExpression("[\\n\\r]"));
         pre.append(line.left(behind));
 
         line = line.mid(behind).trimmed();
@@ -1022,6 +1022,9 @@ LatexTableLine *LatexTableModel::parseNextLine(const QString &text, int &startCo
 			if (line.startsWith(cmd)) {
 				int behind;
 				getCommandOptions(line, cmd.length(), &behind);
+                if(behind>0 && pre.contains('%')){
+                    pre.append('\n');
+                }
 				pre.append(line.left(behind));
 
 				line = line.mid(behind).trimmed();
