@@ -1,5 +1,5 @@
-#ifndef TEXDOCDIALOG_H
-#define TEXDOCDIALOG_H
+#ifndef Header_TexDoc_Dialog
+#define Header_TexDoc_Dialog
 
 #include "mostQtHeaders.h"
 #include "help.h"
@@ -30,7 +30,7 @@ private slots:
 
 private:
 	Ui::TexdocDialog *ui;
-	QRegExpValidator packageNameValidator;
+    QRegularExpressionValidator packageNameValidator;
 	QAbstractButton *openButton;
 	QTimer checkTimer;
 	QString lastDocRequest;
