@@ -1,8 +1,9 @@
-#ifndef UPDATECHECKER_H
-#define UPDATECHECKER_H
+#ifndef Header_UpdateChecker
+#define Header_UpdateChecker
 
 #include "mostQtHeaders.h"
 #include <QNetworkAccessManager>
+#include <QNetworkReply>
 #include "utilsVersion.h"
 
 class UpdateChecker : public QObject
@@ -25,7 +26,7 @@ signals:
 public slots:
 
 private slots:
-	void onRequestError();
+    void onRequestError(QNetworkReply::NetworkError code);
 	void onRequestCompleted();
 
 private:
