@@ -1,14 +1,14 @@
-#ifndef USERMACRO_H
-#define USERMACRO_H
+#ifndef Header_UserMacro
+#define Header_UserMacro
 
 #include "mostQtHeaders.h"
-
+#include "latexdocument.h"
 #include <QJsonDocument>
 #include <QJsonArray>
 
 class QLanguageDefinition;
 class QLanguageFactory;
-class LatexDocument;
+//class LatexDocument;
 
 
 class Macro
