@@ -87,7 +87,12 @@ UserMenuDialog::UserMenuDialog(QWidget *parent,  QString name, QLanguageFactory
 	searchReplacePanel->display(0, false);
 	Q_UNUSED(searchReplacePanelAction)
 
-	ui.tagEdit->layout()->setMargin(0);
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
+    ui.tagEdit->layout()->setMargin(0);
+#else
+    ui.tagEdit->layout()->setContentsMargins(0,0,0,0);
+#endif
+
 	ui.tagEdit->layout()->addWidget(codeedit->editor());
 
     // limit height of description editor
@@ -184,6 +189,16 @@ void UserMenuDialog::selectFirst()
     ui.treeWidget->setCurrentItem(item);
 }
 
+void UserMenuDialog::setLineWrap(bool wrap)
+{
+    codeedit->editor()->setLineWrapping(wrap);
+}
+
+bool UserMenuDialog::getLineWrap()
+{
+    return codeedit->editor()->flag(QEditor::LineWrap);
+}
+
 QTreeWidgetItem *UserMenuDialog::findCreateFolder(const QString &menu)
 {
     QTreeWidgetItem *parent=nullptr;
