@@ -279,7 +279,7 @@ QString getRealIconFile(const QString &icon)
     }
 
 	foreach (const QString &name, iconNames) {
-		if (QFileInfo(name).exists())
+        if (QFileInfo::exists(name))
 			return name;
 	}
 
@@ -359,7 +359,7 @@ bool systemUsesDarkMode(const QPalette &pal)
 
 bool isFileRealWritable(const QString &filename)
 {
-    if(QFileInfo(filename).exists()){
+    if(QFileInfo::exists(filename)){
         return QFileInfo(filename).isWritable();
     }
 
@@ -381,7 +381,7 @@ bool isFileRealWritable(const QString &filename)
  */
 bool isExistingFileRealWritable(const QString &filename)
 {
-	return QFileInfo(filename).exists() && isFileRealWritable(filename);
+    return QFileInfo::exists(filename) && isFileRealWritable(filename);
 }
 
 /*!
@@ -597,11 +597,12 @@ QString getEnvironmentPath()
 	if (path.isNull()) {
 #ifdef Q_OS_MAC
 		QProcess *myProcess = new QProcess();
-        myProcess->start("bash -l -c \"echo -n $PATH\"");  // -n ensures there is no newline at the end
+        myProcess->start("/usr/libexec/path_helper");  // -n ensures there is no newline at the end
+
 		myProcess->waitForFinished(3000);
 		if (myProcess->exitStatus() == QProcess::NormalExit) {
 			QByteArray res = myProcess->readAllStandardOutput();
-			path = QString(res).split('\n').last();  // bash may have some initial output. path is on the last line
+            path = QString(res).split('\"').at(1);  // bash may have some initial output. path is on the last line
 		} else {
 			path = "";
 		}
